@@ -6,23 +6,23 @@
  */
 
 #include "receivefilejob.h"
+#include "bluedevil_kded.h"
 #include "filereceiversettings.h"
 #include "obexagent.h"
-#include "debug_p.h"
 
 #include <QDir>
 #include <QIcon>
-#include <QTimer>
 #include <QTemporaryFile>
+#include <QTimer>
 
 #include <KIO/CopyJob>
-#include <KNotification>
-#include <KLocalizedString>
 #include <KJobTrackerInterface>
+#include <KLocalizedString>
+#include <KNotification>
 
-#include <BluezQt/Manager>
 #include <BluezQt/Adapter>
 #include <BluezQt/Device>
+#include <BluezQt/Manager>
 #include <BluezQt/ObexSession>
 
 ReceiveFileJob::ReceiveFileJob(const BluezQt::Request<QString> &req, BluezQt::ObexTransferPtr transfer, BluezQt::ObexSessionPtr session, ObexAgent *parent)
@@ -32,9 +32,11 @@ ReceiveFileJob::ReceiveFileJob(const BluezQt::Request<QString> &req, BluezQt::Ob
     , m_transfer(transfer)
     , m_session(session)
     , m_request(req)
-    , m_accepted(false)
 {
     setCapabilities(Killable);
+    // Pretend to be BlueDevil's file transfer agent even though we're run inside kded
+    setProperty("desktopFileName", QStringLiteral("org.kde.bluedevilsendfile"));
+    setProperty("immediateProgressReporting", true);
 }
 
 QString ReceiveFileJob::deviceAddress() const
@@ -49,24 +51,24 @@ void ReceiveFileJob::start()
 
 bool ReceiveFileJob::doKill()
 {
-    qCDebug(BLUEDAEMON) << "ReceiveFileJob-Kill";
+    qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Kill";
     m_transfer->cancel();
     return true;
 }
 
 void ReceiveFileJob::init()
 {
-    qCDebug(BLUEDAEMON) << "ReceiveFileJob:";
-    qCDebug(BLUEDAEMON) << "\tName:" << m_transfer->name();
-    qCDebug(BLUEDAEMON) << "\tFilename:" << m_transfer->fileName();
-    qCDebug(BLUEDAEMON) << "\tStatus:" << m_transfer->status();
-    qCDebug(BLUEDAEMON) << "\tType:" << m_transfer->type();
-    qCDebug(BLUEDAEMON) << "\tSize:" << m_transfer->size();
-    qCDebug(BLUEDAEMON) << "\tTransferred:" << m_transfer->transferred();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob:";
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tName:" << m_transfer->name();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tFilename:" << m_transfer->fileName();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tStatus:" << m_transfer->status();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tType:" << m_transfer->type();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tSize:" << m_transfer->size();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tTransferred:" << m_transfer->transferred();
 
-    qCDebug(BLUEDAEMON) << "ObexSession:";
-    qCDebug(BLUEDAEMON) << "\tSource:" << m_session->source();
-    qCDebug(BLUEDAEMON) << "\tDestination:" << m_session->destination();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "ObexSession:";
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tSource:" << m_session->source();
+    qCDebug(BLUEDEVIL_KDED_LOG) << "\tDestination:" << m_session->destination();
 
     connect(m_transfer.data(), &BluezQt::ObexTransfer::statusChanged, this, &ReceiveFileJob::statusChanged);
     connect(m_transfer.data(), &BluezQt::ObexTransfer::transferredChanged, this, &ReceiveFileJob::transferredChanged);
@@ -75,14 +77,14 @@ void ReceiveFileJob::init()
 
     BluezQt::AdapterPtr adapter = m_agent->manager()->adapterForAddress(m_session->source());
     if (!adapter) {
-        qCDebug(BLUEDAEMON) << "No adapter for" << m_session->source();
+        qCDebug(BLUEDEVIL_KDED_LOG) << "No adapter for" << m_session->source();
         showNotification();
         return;
     }
 
     BluezQt::DevicePtr device = adapter->deviceForAddress(m_session->destination());
     if (!device) {
-        qCDebug(BLUEDAEMON) << "No device for" << m_session->destination();
+        qCDebug(BLUEDEVIL_KDED_LOG) << "No device for" << m_session->destination();
         showNotification();
         return;
     }
@@ -103,7 +105,7 @@ void ReceiveFileJob::init()
 
     case 1: // Auto-accept only from trusted devices
         if (device->isTrusted()) {
-            qCDebug(BLUEDAEMON) << "Auto-accepting transfer for trusted device";
+            qCDebug(BLUEDEVIL_KDED_LOG) << "Auto-accepting transfer for trusted device";
             slotAccept();
         } else {
             showNotification();
@@ -111,7 +113,7 @@ void ReceiveFileJob::init()
         break;
 
     case 2: // Auto-accept all transfers
-        qCDebug(BLUEDAEMON) << "Auto-accepting transfers for all devices";
+        qCDebug(BLUEDEVIL_KDED_LOG) << "Auto-accepting transfers for all devices";
         slotAccept();
         break;
 
@@ -123,13 +125,13 @@ void ReceiveFileJob::init()
 
 void ReceiveFileJob::showNotification()
 {
-    KNotification *notification = new KNotification(QStringLiteral("IncomingFile"),
-                                                      KNotification::Persistent, this);
+    KNotification *notification = new KNotification(QStringLiteral("IncomingFile"), KNotification::Persistent, this);
 
     notification->setTitle(QStringLiteral("%1 (%2)").arg(m_deviceName.toHtmlEscaped(), m_deviceAddress));
-    notification->setText(i18nc(
-        "Show a notification asking to authorize or deny an incoming file transfer to this computer from a Bluetooth device.",
-        "%1 is sending you the file %2", m_deviceName.toHtmlEscaped(), m_transfer->name()));
+    notification->setText(i18nc("Show a notification asking to authorize or deny an incoming file transfer to this computer from a Bluetooth device.",
+                                "%1 is sending you the file %2",
+                                m_deviceName.toHtmlEscaped(),
+                                m_transfer->name()));
 
     QStringList actions;
     actions.append(i18nc("Button to accept the incoming file transfer and download it in the default download directory", "Accept"));
@@ -148,7 +150,7 @@ void ReceiveFileJob::showNotification()
 
 void ReceiveFileJob::slotAccept()
 {
-    qCDebug(BLUEDAEMON) << "ReceiveFileJob-Accept";
+    qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Accept";
 
     KIO::getJobTracker()->registerJob(this);
 
@@ -156,12 +158,15 @@ void ReceiveFileJob::slotAccept()
     m_targetPath = FileReceiverSettings::self()->saveUrl().adjusted(QUrl::StripTrailingSlash);
     m_targetPath.setPath(m_targetPath.path() + QLatin1Char('/') + m_transfer->name());
 
-    Q_EMIT description(this, i18n("Receiving file over Bluetooth"),
-                    QPair<QString, QString>(i18nc("File transfer origin", "From"), m_deviceName),
-                    QPair<QString, QString>(i18nc("File transfer destination", "To"), m_targetPath.toDisplayString()));
+    setTotalAmount(Files, 1);
+
+    Q_EMIT description(this,
+                       i18nc("@title job", "Receiving file"),
+                       QPair<QString, QString>(i18nc("File transfer origin", "From"), m_deviceName),
+                       QPair<QString, QString>(i18nc("File transfer destination", "To"), m_targetPath.toDisplayString()));
 
     m_tempPath = createTempPath(m_transfer->name());
-    qCDebug(BLUEDAEMON) << "TempPath" << m_tempPath;
+    qCDebug(BLUEDEVIL_KDED_LOG) << "TempPath" << m_tempPath;
 
     m_accepted = true;
     m_request.accept(m_tempPath);
@@ -170,7 +175,7 @@ void ReceiveFileJob::slotAccept()
 void ReceiveFileJob::slotCancel()
 {
     if (!m_accepted && m_transfer->status() == BluezQt::ObexTransfer::Queued) {
-        qCDebug(BLUEDAEMON) << "Cancel Push";
+        qCDebug(BLUEDEVIL_KDED_LOG) << "Cancel Push";
         m_request.reject();
         setError(KJob::UserDefinedError);
         emitResult();
@@ -180,33 +185,31 @@ void ReceiveFileJob::slotCancel()
 void ReceiveFileJob::moveFinished(KJob *job)
 {
     if (job->error()) {
-        qCDebug(BLUEDAEMON) << job->error();
-        qCDebug(BLUEDAEMON) << job->errorText();
+        qCDebug(BLUEDEVIL_KDED_LOG) << job->error();
+        qCDebug(BLUEDEVIL_KDED_LOG) << job->errorText();
         setError(job->error());
         setErrorText(i18n("Saving file failed"));
 
         QFile::remove(m_tempPath);
     }
 
-    // Delay emitResult to make sure notification is displayed even
-    // for very small files that are received instantly
-    QTimer::singleShot(500, this, [this]() {
-        emitResult();
-    });
+    setProcessedAmount(Files, 1);
+
+    emitResult();
 }
 
 void ReceiveFileJob::statusChanged(BluezQt::ObexTransfer::Status status)
 {
     switch (status) {
     case BluezQt::ObexTransfer::Active:
-        qCDebug(BLUEDAEMON) << "ReceiveFileJob-Transfer Active";
+        qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Transfer Active";
         setTotalAmount(Bytes, m_transfer->size());
         setProcessedAmount(Bytes, 0);
         m_time = QTime::currentTime();
         break;
 
     case BluezQt::ObexTransfer::Complete: {
-        qCDebug(BLUEDAEMON) << "ReceiveFileJob-Transfer Complete";
+        qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Transfer Complete";
         KIO::CopyJob *job = KIO::move(QUrl::fromLocalFile(m_tempPath), m_targetPath, KIO::HideProgressInfo);
         job->setUiDelegate(nullptr);
         connect(job, &KIO::CopyJob::finished, this, &ReceiveFileJob::moveFinished);
@@ -214,7 +217,7 @@ void ReceiveFileJob::statusChanged(BluezQt::ObexTransfer::Status status)
     }
 
     case BluezQt::ObexTransfer::Error:
-        qCDebug(BLUEDAEMON) << "ReceiveFileJob-Transfer Error";
+        qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Transfer Error";
         setError(KJob::UserDefinedError);
         setErrorText(i18n("Bluetooth transfer failed"));
 
@@ -226,14 +229,14 @@ void ReceiveFileJob::statusChanged(BluezQt::ObexTransfer::Status status)
         break;
 
     default:
-        qCDebug(BLUEDAEMON) << "Not implemented status: " << status;
+        qCDebug(BLUEDEVIL_KDED_LOG) << "Not implemented status: " << status;
         break;
     }
 }
 
 void ReceiveFileJob::transferredChanged(quint64 transferred)
 {
-    // qCDebug(BLUEDAEMON) << "ReceiveFileJob-Transferred" << transferred;
+    // qCDebug(BLUEDEVIL_KDED_LOG) << "ReceiveFileJob-Transferred" << transferred;
 
     // If at least 1 second has passed since last update
     int secondsSinceLastTime = m_time.secsTo(QTime::currentTime());
